From f0c525c4cc42066ffcdf5c182d0335ccf7b0b4f9 Mon Sep 17 00:00:00 2001
From: Jeremy Huddleston Sequoia <jeremyhu@apple.com>
Date: Tue, 20 Dec 2016 12:41:21 -0800
Subject: [PATCH 8/8] Fix build issues pre-Lion due to missing a strnlen
 definition

https://trac.macports.org/ticket/51520
https://llvm.org/bugs/show_bug.cgi?id=27714

Signed-off-by: Jeremy Huddleston Sequoia <jeremyhu@apple.com>
(cherry picked from commit 72752ce2c259fdbc1a7d6a6e098e6a215233b823)
---
 lib/ObjectYAML/MachOYAML.cpp           | 14 ++++++++++++++
 tools/llvm-pdbdump/LLVMOutputStyle.cpp | 14 ++++++++++++++
 tools/obj2yaml/macho2yaml.cpp          | 16 +++++++++++++++-
 3 files changed, 43 insertions(+), 1 deletion(-)

diff --git llvm_release_39/lib/ObjectYAML/MachOYAML.cpp macports_release_39/lib/ObjectYAML/MachOYAML.cpp
index d819e80836c..4b88a5032bb 100644
--- llvm_release_39/lib/ObjectYAML/MachOYAML.cpp
+++ macports_release_39/lib/ObjectYAML/MachOYAML.cpp
@@ -18,6 +18,20 @@
 
 #include <string.h> // For memcpy, memset and strnlen.
 
+#ifdef __APPLE__
+#include <Availability.h>
+#if __MAC_OS_X_VERSION_MIN_REQUIRED < 1070
+static size_t strnlen(const char *s, size_t maxlen) {
+  size_t l = 0;
+  while (l < maxlen && *s) {
+    l++;
+    s++;
+  }
+  return l;
+}
+#endif
+#endif
+
 namespace llvm {
 
 MachOYAML::LoadCommand::~LoadCommand() {}
diff --git llvm_release_39/tools/llvm-pdbdump/LLVMOutputStyle.cpp macports_release_39/tools/llvm-pdbdump/LLVMOutputStyle.cpp
index 6d94295d126..0b558115497 100644
--- llvm_release_39/tools/llvm-pdbdump/LLVMOutputStyle.cpp
+++ macports_release_39/tools/llvm-pdbdump/LLVMOutputStyle.cpp
@@ -29,6 +29,20 @@
 
 #include <unordered_map>
 
+#ifdef __APPLE__
+#include <Availability.h>
+#if __MAC_OS_X_VERSION_MIN_REQUIRED < 1070
+static size_t strnlen(const char *s, size_t maxlen) {
+  size_t l = 0;
+  while (l < maxlen && *s) {
+    l++;
+    s++;
+  }
+  return l;
+}
+#endif
+#endif
+
 using namespace llvm;
 using namespace llvm::codeview;
 using namespace llvm::pdb;
diff --git llvm_release_39/tools/obj2yaml/macho2yaml.cpp macports_release_39/tools/obj2yaml/macho2yaml.cpp
index c9a1385f173..22029f21588 100644
--- llvm_release_39/tools/obj2yaml/macho2yaml.cpp
+++ macports_release_39/tools/obj2yaml/macho2yaml.cpp
@@ -14,7 +14,21 @@
 #include "llvm/Support/ErrorHandling.h"
 #include "llvm/Support/LEB128.h"
 
-#include <string.h> // for memcpy
+#include <string.h> // for memcpy abd strnlen
+
+#ifdef __APPLE__
+#include <Availability.h>
+#if __MAC_OS_X_VERSION_MIN_REQUIRED < 1070
+static size_t strnlen(const char *s, size_t maxlen) {
+  size_t l = 0;
+  while (l < maxlen && *s) {
+    l++;
+    s++;
+  }
+  return l;
+}
+#endif
+#endif
 
 using namespace llvm;
 
-- 
2.11.0

